@@ -83,10 +83,10 @@ class Source(SourceBase):
 
         New ScopeSim-style input
         - ``table=<astropy.Table>, spectra=<list of synphot.SourceSpectrum>``
-        - ``table=<astropy.Table>, lam=<array>, spectra=<list of array>
+        - ``table=<astropy.Table>, lam=<array>, spectra=<list of array>``
         - ``image_hdu=<fits.ImageHDU>, spectra=<list of synphot.SourceSpectrum>``
-        - ``image_hdu=<fits.ImageHDU>, lam=<array>, spectra=<list of array>
-        - ``image_hdu=<fits.ImageHDU>, flux=<astropy.Quantity>
+        - ``image_hdu=<fits.ImageHDU>, lam=<array>, spectra=<list of array>``
+        - ``image_hdu=<fits.ImageHDU>, flux=<astropy.Quantity>``
 
         Old SimCADO-style input
         - ``x=<array>, y=<array>, ref=<array>, spectra=<list of synphot.SourceSpectrum>``
@@ -479,6 +479,17 @@ class Source(SourceBase):
     #                               lookup_table=fluxes)
 
     def shift(self, dx=0, dy=0, layers=None):
+        """
+        Shifts the position of one or more fields w.r.t. the optical axis
+
+        Parameters
+        ----------
+        dx, dy : float
+            [arcsec]
+        layers : list of ints
+            which .fields entries to shift
+
+        """
 
         if layers is None:
             layers = np.arange(len(self.fields))
@@ -507,8 +518,6 @@ class Source(SourceBase):
 
         self.bandpass = bandpass
 
-
-
     def plot(self):
         """
         Plot the location of source components
